# py-listmonk

[![PyPI - Version](https://img.shields.io/pypi/v/py-listmonk.svg)](https://pypi.org/project/py-listmonk)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/py-listmonk.svg)](https://pypi.org/project/py-listmonk)
[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install py-listmonk
```

## License

`py-listmonk` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
